Authors
=======

Initial developers
------------------

* Stephan Richter (stephan.richter <at> gmail.com)
* Roger Ineichen (roger <at> projekt01.ch)

Contributors
------------

* Adam Groszer
* Axel Muller
* Brian Sutherland
* Carsten Senger
* Christian Zagrodnick
* Christopher Combelles
* Dan Korostelev
* Daniel Nouri
* Darryl Cousins
* David Glick
* Herman Himmelbauer
* Jacob Holm
* Laurent Mignon
* Malthe Borch
* Marius Gedminas
* Martijn Faassen
* Martin Aspeli
* Michael Howitz
* Michael Kerrin
* Paul Carduner
* Dylan Jay
* Chris Calloway
* Jean-Paul Ladage
